"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const privilegeService = require("../privilege/service");
const userService = require("../user/service");
const types_1 = require("../user/types");
const html_1 = require("./formats/html");
class CreateUserController extends controller_1.default {
    async get(ctx) {
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege can create new users');
        }
        ctx.response.type = 'text/html';
        ctx.response.body = html_1.createUserForm(ctx.query.msg, ctx.query.error);
    }
    async post(ctx) {
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege can create new users');
        }
        const identity = ctx.request.body.identity;
        const nickname = ctx.request.body.nickname;
        const type = ctx.request.body.type;
        if (!identity || !identity.includes(':') || identity.includes(' ')) {
            throw new http_errors_1.UnprocessableEntity('Identity must exist and must be a url');
        }
        if (nickname.length < 1) {
            throw new http_errors_1.UnprocessableEntity('nickname must contain at least 1 character');
        }
        if (!types_1.UserTypeList.includes(type)) {
            throw new http_errors_1.UnprocessableEntity('type must be one of ' + types_1.UserTypeList.join(', '));
        }
        try {
            await userService.findByIdentity(ctx.request.body.identity);
            ctx.status = 303;
            ctx.response.headers.set('Location', '/create-user?error=User+already+exists');
            return;
        }
        catch (err) {
            if (!(err instanceof http_errors_1.NotFound)) {
                throw err;
            }
        }
        const newUser = await userService.save({
            identity: identity,
            nickname: nickname,
            created: new Date(),
            type: type,
            active: 'active' in ctx.request.body
        });
        ctx.response.status = 303;
        ctx.response.headers.set('Location', '/user/' + newUser.id);
    }
}
exports.default = new CreateUserController();
//# sourceMappingURL=controller.js.map