"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.replaceMembers = exports.addMemberToGroup = exports.findMembers = exports.isGroup = void 0;
const database_1 = require("../database");
const UserService = require("../user/service");
/**
 *  Checks if the user is a type group and returns true or false
 */
function isGroup(user) {
    return user.type === 'group';
}
exports.isGroup = isGroup;
/**
 * Finding group members
 */
async function findMembers(group) {
    const query = `SELECT ${UserService.fieldNames.join(', ')} FROM users INNER JOIN group_members ON users.id = group_members.user_id WHERE group_id = ?`;
    const result = await database_1.default.query(query, [group.id]);
    const models = [];
    for (const record of result[0]) {
        const model = UserService.recordToModel(record);
        models.push(model);
    }
    return models;
}
exports.findMembers = findMembers;
async function addMemberToGroup(group, user) {
    const query = 'INSERT INTO group_members SET group_id = ?, user_id = ?';
    await database_1.default.query(query, [group.id, user.id]);
}
exports.addMemberToGroup = addMemberToGroup;
async function replaceMembers(group, users) {
    const connection = await database_1.default.getConnection();
    await connection.beginTransaction();
    try {
        await connection.query('DELETE FROM group_members WHERE group_id = ?', [group.id]);
        for (const user of users) {
            await connection.query('INSERT INTO group_members SET group_id = ?, user_id = ?', [group.id, user.id]);
        }
        await connection.commit();
    }
    catch (err) {
        await connection.rollback();
        throw err;
    }
    finally {
        connection.release();
    }
}
exports.replaceMembers = replaceMembers;
//# sourceMappingURL=service.js.map