"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const bodyparser_1 = require("@curveball/bodyparser");
const core_1 = require("@curveball/core");
const problem_1 = require("@curveball/problem");
const session_1 = require("@curveball/session");
const session_redis_1 = require("@curveball/session-redis");
const browser_1 = require("@curveball/browser");
const login_1 = require("./middleware/login");
const routes_1 = require("./routes");
const links_1 = require("@curveball/links");
/**
 * The 'main middleware'.
 *
 * Most of the application is expressed as a single middleware. This could
 * potentially allow a12nserver to be embedded in another curveball
 * application.
 */
function default_1() {
    if (process.env.PUBLIC_URI === undefined) {
        throw new Error('PUBLIC_URI environment variable must be set.');
    }
    const middlewares = [
        browser_1.default({
            title: 'a12n-server',
        }),
        problem_1.default(),
        links_1.default(),
        session_1.default({
            store: process.env.REDIS_HOST ? new session_redis_1.RedisStore({
                prefix: 'A12N-session',
                clientOptions: {
                    port: process.env.REDIS_PORT ? parseInt(process.env.REDIS_PORT, 10) : 6379,
                    host: process.env.REDIS_HOST ? process.env.REDIS_HOST : '127.0.0.1',
                },
            }) : 'memory',
            cookieName: 'A12N',
            expiry: 60 * 60 * 24 * 7,
        }),
        login_1.default(),
        bodyparser_1.default(),
        ...routes_1.default,
    ];
    /**
     * This middleware contains all the a12n-server functionality.
     */
    return ctx => {
        return core_1.invokeMiddlewares(ctx, middlewares);
    };
}
exports.default = default_1;
//# sourceMappingURL=main-mw.js.map