"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addPrivilegeForUser = exports.findPrivilege = exports.findPrivileges = exports.hasPrivilege = exports.getPrivilegesForUser = void 0;
const database_1 = require("../database");
const database_2 = require("../database");
async function getPrivilegesForUser(user) {
    const query = 'SELECT resource, privilege FROM user_privileges WHERE user_id = ?';
    const result = await database_1.default.query(query, [user.id]);
    return result[0].reduce((currentPrivileges, row) => {
        const privileges = Object.assign({}, currentPrivileges);
        // eslint-disable-next-line no-prototype-builtins
        if (privileges.hasOwnProperty(row.resource)) {
            if (privileges[row.resource].indexOf(row.privilege) === -1) {
                privileges[row.resource].push(row.privilege);
            }
        }
        else {
            privileges[row.resource] = [row.privilege];
        }
        return privileges;
    }, {});
}
exports.getPrivilegesForUser = getPrivilegesForUser;
async function hasPrivilege(who, privilege, resource = '*') {
    let user;
    if (isContext(who)) {
        if (!who.state.user) {
            throw new Error('Cannot check privilege for unauthenticated user');
        }
        user = who.state.user;
    }
    else {
        user = who;
    }
    const query = 'SELECT id FROM user_privileges WHERE user_id = ? AND privilege = ? AND (resource = ? OR resource = "*")';
    const result = await database_1.default.query(query, [user.id, privilege, resource]);
    return result[0].length === 1;
}
exports.hasPrivilege = hasPrivilege;
function isContext(input) {
    return input.request !== undefined && input.response !== undefined;
}
async function findPrivileges() {
    const query = `
  SELECT privileges.privilege, privileges.description FROM privileges
  UNION ALL
  SELECT DISTINCT user_privileges.privilege, null FROM user_privileges
  LEFT JOIN privileges
  ON privileges.privilege = user_privileges.privilege
  WHERE privileges.privilege IS NULL
  `;
    const result = await database_2.default.query(query);
    return result[0];
}
exports.findPrivileges = findPrivileges;
async function findPrivilege(privilege) {
    const query = 'SELECT privilege, description FROM privileges WHERE privilege = ?';
    const result = await database_2.default.query(query, [privilege]);
    if (result[0].length !== 1) {
        return {
            privilege: privilege,
            description: ''
        };
    }
    return result[0][0];
}
exports.findPrivilege = findPrivilege;
async function addPrivilegeForUser(user, privilege, resource) {
    const query = 'INSERT INTO user_privileges SET ?';
    await database_2.default.query(query, [
        {
            user_id: user.id,
            privilege,
            resource,
        }
    ]);
}
exports.addPrivilegeForUser = addPrivilegeForUser;
//# sourceMappingURL=service.js.map