"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const privilegeService = require("../../privilege/service");
const hal = require("../formats/hal");
const usersService = require("../service");
const types_1 = require("../types");
class UserCollectionController extends controller_1.default {
    async get(ctx) {
        const users = await usersService.findAll();
        ctx.response.body = hal.collection(users);
    }
    async post(ctx) {
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege may create new users');
        }
        const userBody = ctx.request.body;
        try {
            await usersService.findByIdentity(userBody._links.me.href);
            throw new http_errors_1.Conflict('User already exists');
        }
        catch (err) {
            if (!(err instanceof http_errors_1.NotFound)) {
                throw err;
            }
        }
        if (typeof userBody.nickname !== 'string') {
            throw new http_errors_1.UnprocessableEntity('nickname must be a string');
        }
        if (typeof userBody.active !== 'boolean') {
            throw new http_errors_1.UnprocessableEntity('active must be a boolean');
        }
        if (!types_1.UserTypeList.includes(userBody.type)) {
            throw new http_errors_1.UnprocessableEntity('type must be one of ' + types_1.UserTypeList.join(', '));
        }
        const user = await usersService.save(hal.halToModel(userBody));
        ctx.response.status = 201;
        ctx.response.headers.set('Location', `/user/${user.id}`);
    }
}
exports.default = new UserCollectionController();
//# sourceMappingURL=collection.js.map